<?php
/**
*
* @package phpBB Extension - eparsons/restapi
* @copyright (c) 2018 Eric Parsons, (copyleft) 2023 Tomáš Valenta
* @license https://opensource.org/licenses/GPL-2.0 GNU General Public License v2
*
*/
namespace eparsons\restapi\controller\forums;

use eparsons\restapi\ErrorResponse;
use eparsons\restapi\Validation;
use phpbb\config\config;
use phpbb\user;
use phpbb\auth;
use Symfony\Component\HttpFoundation\JsonResponse;

if (!defined('IN_PHPBB'))
{
    exit();
}

class Forums
{
    /**
    * phpBB user
    *
    * @var user
    */
    private $user;

    /**
    * REST API validator
    *
    * @var Validation
    */
    private $validation;

    /**
     * Constructor
     *
     * @param user $user
     * @param Validation $validation
     */
    public function __construct(user $user, Validation $validation)
    {
        $this->user = $user;
        $this->validation = $validation;
    }

    /**
    * Handler for /api/forums/{forum_id}/threads GET requests
    *
    * @return JsonResponse A Symfony Response object
    */
    public function viewThreads($forum_id)
    {
        $errorResponse = $this->validation->ValidateRequest('GET');
        if ($errorResponse != null)
        {
            return $errorResponse;
        }

        $forum_id = (int)$forum_id;

        global $db, $phpbb_container, $table_prefix, $request;

        $phpbb_content_visibility = $phpbb_container->get('content.visibility');

        $request->enable_super_globals();

        if (!isset($_GET["token"])) {
            http_response_code(400);
            die();
        }

        $api_token_query = $db->sql_query(
            'SELECT user_id, allowed_forum_ids
            FROM ' . $table_prefix . 'api_tokens
            WHERE token=\'' . $db->sql_escape($_GET["token"]) . '\''
        );

        $request->disable_super_globals();

        $user_id = null;
        $allowed_forum_ids = array();

        while ($row = $db->sql_fetchrow($api_token_query)) {
            $user_id = $row["user_id"];
            $allowed_forum_ids = explode(",", $row["allowed_forum_ids"]);

            foreach ($allowed_forum_ids as &$allowed_forum_id) {
                $allowed_forum_id = (int)$allowed_forum_id;
            }
        }

        if ($user_id === null) {
            http_response_code(401);
            die();
        }

        if (!in_array($forum_id, $allowed_forum_ids)) {
            http_response_code(401);
            die();
        }

        $threads_query = $db->sql_query(
            'SELECT *
            FROM ' . TOPICS_TABLE . ' 
            WHERE
                forum_id = ' . $forum_id . '
                AND ' . $phpbb_content_visibility->get_visibility_sql('topic', $forum_id) . '
            ORDER BY topic_id DESC
            LIMIT 25'
        );

        $topics = array();

        while ($row = $db->sql_fetchrow($threads_query))
        {
            $topic = array();
            $topic["id"] = $row["topic_id"];
            $topic["title"] = $row["topic_title"];
            $topic["time"] = (int)$row["topic_time"];

            $first_post_query = $db->sql_query(
                'SELECT *
                FROM ' . POSTS_TABLE . ' 
                WHERE
                    topic_id = ' . $row["topic_id"] . '
                    AND ' . $phpbb_content_visibility->get_visibility_sql('post', $forum_id) . '
                ORDER BY post_id DESC'
            );

            while ($first_post_row = $db->sql_fetchrow($first_post_query))
            {
                $topic["content"] = $first_post_row["post_text"];
            }

            array_push($topics, $topic);
        }

        $forum_query = $db->sql_query(
            'SELECT forum_name, forum_desc
            FROM ' . FORUMS_TABLE . '
            WHERE forum_id= ' . $forum_id
        );

        $forum = array();

        while ($row = $db->sql_fetchrow($forum_query)) {
            $forum["name"] = $row["forum_name"];
            $forum["desc"] = $row["forum_desc"];
        }

        return new JsonResponse(
            array(
                "forum" => $forum,
                "topics" => $topics,
            ),
            200
        );
    }
}
